@@ -17,6 +17,7 @@ except ImportError:
     import StringIO
 
 from docutils import nodes
+from docutils.parsers.rst import directives
 from docutils.statemachine import ViewList
 
 from sphinx.util import force_decode
@@ -26,28 +27,7 @@ from sphinx.util.docstrings import prepare_docstring
 from sphinx.pycode import ModuleAnalyzer
 
 from sphinxcontrib import httpdomain
-
-
-def import_object(import_name):
-    module_name, expr = import_name.split(':', 1)
-    mod = __import__(module_name)
-    mod = reduce(getattr, module_name.split('.')[1:], mod)
-    globals = __builtins__
-    if not isinstance(globals, dict):
-        globals = globals.__dict__
-    return eval(expr, globals, mod.__dict__)
-
-
-def http_directive(method, path, content):
-    method = method.lower().strip()
-    if isinstance(content, basestring):
-        content = content.splitlines()
-    yield ''
-    yield '.. http:{method}:: {path}'.format(**locals())
-    yield ''
-    for line in content:
-        yield '   ' + line
-    yield ''
+from sphinxcontrib.autohttp.common import http_directive, import_object
 
 
 def translate_werkzeug_rule(rule):
@@ -78,42 +58,48 @@ class AutoflaskDirective(Directive):
 
     has_content = True
     required_arguments = 1
-    option_spec = {'endpoints': str,
-                   'undoc-endpoints': str,
-                   'undoc-blueprints': str,
-                   'undoc-static': str,
-                   'include-empty-docstring': str}
+    option_spec = {'endpoints': directives.unchanged,
+                   'blueprints': directives.unchanged,
+                   'undoc-endpoints': directives.unchanged,
+                   'undoc-blueprints': directives.unchanged,
+                   'undoc-static': directives.unchanged,
+                   'include-empty-docstring': directives.unchanged}
 
     @property
     def endpoints(self):
-        try:
-            endpoints = re.split(r'\s*,\s*', self.options['endpoints'])
-        except KeyError:
-            # means 'endpoints' option was missing
+        endpoints = self.options.get('endpoints', None)
+        if not endpoints:
             return None
-        return frozenset(endpoints)
+        return frozenset(re.split(r'\s*,\s*', endpoints))
 
     @property
     def undoc_endpoints(self):
-        try:
-            endpoints = re.split(r'\s*,\s*', self.options['undoc-endpoints'])
-        except KeyError:
+        undoc_endpoints = self.options.get('undoc-endpoints', None)
+        if not undoc_endpoints:
             return frozenset()
-        return frozenset(endpoints)
+        return frozenset(re.split(r'\s*,\s*', undoc_endpoints))
+
+    @property
+    def blueprints(self):
+        blueprints = self.options.get('blueprints', None)
+        if not blueprints:
+            return None
+        return frozenset(re.split(r'\s*,\s*', blueprints))
 
     @property
     def undoc_blueprints(self):
-        try:
-            blueprints = re.split(r'\s*,\s*', self.options['undoc-blueprints'])
-        except KeyError:
+        undoc_blueprints = self.options.get('undoc-blueprints', None)
+        if not undoc_blueprints:
             return frozenset()
-        return frozenset(blueprints)
+        return frozenset(re.split(r'\s*,\s*', undoc_blueprints))
 
     def make_rst(self):
         app = import_object(self.arguments[0])
         for method, path, endpoint in get_routes(app):
             try:
                 blueprint, endpoint_internal = endpoint.split('.')
+                if self.blueprints and blueprint not in self.blueprints:
+                    continue
                 if blueprint in self.undoc_blueprints:
                     continue
             except ValueError:
